@@ -26,11 +26,11 @@ use strict;
 use Getopt::Long qw(:config pass_through no_auto_abbrev);
 
 my $app_name     = 'colordiff';
-my $version      = '1.0.21';
+my $version      = '1.0.22';
 my $author       = 'Dave Ewart';
 my $author_email = 'davee@sungate.co.uk';
 my $app_www      = 'http://www.colordiff.org/';
-my $copyright    = '(C)2002-2022';
+my $copyright    = '(C)2002-2026';
 my $show_banner  = 1;
 my $diff_cmd     = "diff";
 
@@ -497,13 +497,13 @@ if ($diff_type eq 'diffy') {
             next if ($separator_col{$i} == 0);
             next if ($_ =~ /^(Index: |={4,}|RCS file: |retrieving |diff )/);
             my $subsub = substr ($_, $i, 2);
-            if ($subsub !~ / [ (|<>]/) {
+            if ($subsub !~ / [ (|<>\\\/]/) {
                 $separator_col{$i} = 0;
                 if ($candidate_col{$i} > 0) {
                     $possible_cols--;
                 }
             }
-            if ($subsub =~ / [|<>]/) {
+            if ($subsub =~ / [|<>\\\/]/) {
                 $candidate_col{$i}++;
                 if ($candidate_col{$i} == 1) {
                     $possible_cols++;
@@ -548,8 +548,8 @@ if ($diff_type eq 'diffy') {
 my $count_marks = 1;
 
 while (defined( $_ = @inputstream ? shift @inputstream : ($lastline and <$inputhandle>) )) {
-    if (/^Binary files (.*) and (.*) differ$/) {
-        print "Binary files $file_old$1$plain_text and $file_new$2$plain_text differ\n";
+    if (($diffy_sep_col == 0) && (/^Binary files (.*) and (.*) differ$/)) {
+        print "Binary files $file_old$1$plain_text and $file_new$2$plain_text differ$colour{off}\n";
         next;
     }
     if ($diff_type eq 'diff') {
@@ -650,7 +650,7 @@ while (defined( $_ = @inputstream ? shift @inputstream : ($lastline and <$inputh
             if ($sepchars eq ' <') {
                 print "$file_old";
             }
-            elsif ($sepchars eq ' |') {
+            elsif ($sepchars eq ' |' || $sepchars eq ' /' || $sepchars eq ' \\') {
                 print "$diff_stuff";
             }
             elsif ($sepchars eq ' >') {
